"""Installation file for the ansys-api-modelcenter package"""

import os
from datetime import datetime

import setuptools
from ansys.tools.protoc_helper import CMDCLASS_OVERRIDE

# Get the long description from the README file
HERE = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(HERE, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

product = "modelcenter"
library = ""
package_info = ["ansys", "api", product, library, "v0"]
username = "ansys"
package_name = "ansys-api-modelcenter"

with open(
    os.path.join(HERE, "ansys", "api", product, library, "VERSION"), encoding="utf-8"  # noqa : E501
) as f:  # noqa : E501
    version = f.read().strip()
dot_package_name = ".".join(filter(None, package_info))


description = f"Autogenerated Python gRPC interface package for {package_name}, built on {datetime.now().strftime('%H:%M:%S on %d %B %Y')}"  # noqa : E501

if __name__ == "__main__":
    setuptools.setup(
        name=package_name,
        version=version,
        author="ANSYS, Inc.",
        author_email="pyansys.core@ansys.com",
        maintainer="ANSYS, Inc.",
        maintainer_email="pyansys.core@ansys.com",
        description=description,
        long_description=long_description,
        long_description_content_type="text/markdown",
        url=f"https://github.com/{username}/{package_name}",
        license="MIT",
        python_requires=">=3.8",
        install_requires=["grpcio~=1.47", "protobuf~=3.19"],
        packages=setuptools.find_namespace_packages(".", include=("ansys.*",)),
        package_data={
            "": ["*.proto", "*.pyi", "py.typed", "VERSION"],
        },
        entry_points={
            "ansys.tools.protoc_helper.proto_provider": [
                f"{dot_package_name}={dot_package_name}"
            ],  # noqa : E501
        },
        cmdclass=CMDCLASS_OVERRIDE,
        project_urls={
            "Documentation": f"https://github.com/{username}/{package_name}/#readme",  # noqa : E501
            "Source": f"https://github.com/{username}/{package_name}/",  # noqa : E501
            "Tracker": f"https://github.com/{username}/{package_name}/issues/",  # noqa : E501
        },
    )
